@@ -724,7 +724,12 @@ sub _createMailbox {
             &OBM::toolBox::write_log( "[Cyrus::cyrusEngine]: erreur Cyrus : ".$cyrusSrvConn->error(), "W" );
         }
             
-        &OBM::toolBox::write_log( "[Cyrus::cyrusEngine]: verifiez que la version de Cyrus (2.1 min) et que l'option 'allowusermoves' est active !", "W" );
+        &OBM::toolBox::write_log( "[Cyrus::cyrusEngine]: verifiez que la version de Cyrus (2.2 min) et que l'option 'allowusermoves' est active !", "W" );
+        return 0;
+    }
+
+    # On crée les répertoires par défaut si nécessaire
+    if( !$self->_createMailboxDefaultFolders( $cyrusSrv, $object ) ) {
         return 0;
     }
 
@@ -733,9 +738,51 @@ sub _createMailbox {
         return 0;
     }
 
+
     return $returnCode;
 }
 
+sub _createMailboxDefaultFolders {
+    my $self = shift;
+    my( $cyrusSrv, $object ) = @_;
+
+    if( !defined($cyrusSrv->{"imap_server_conn"}) ) {
+        return 0;
+    }
+    my $cyrusSrvConn = $cyrusSrv->{"imap_server_conn"};
+    
+    if( !defined($object) ) {
+        return 0;
+    }
+
+    my $boxName = $object->getMailboxName( "current" );
+    my $boxPrefix = $object->getMailboxPrefix();
+    my $boxPartition = $object->getMailboxPartition();
+    my $boxDefaultFolders = $object->getMailboxDefaultFolders();
+
+    if( !defined($boxDefaultFolders) ) {
+        return 1;
+    }
+
+    my $folderError = 0;
+    foreach my $folder ( @{$boxDefaultFolders} ) {
+        $cyrusSrvConn->create( $boxPrefix.$folder, $boxPartition );
+
+        if( $cyrusSrvConn->error() ) {
+            &OBM::toolBox::write_log( "[Cyrus::cyrusEngine]: Erreur lors de la creation du repertoire '".$folder."'", "W" );
+            $folderError++;
+        }else {
+            &OBM::toolBox::write_log( "[Cyrus::cyrusEngine]: Creation du repertoire '".$folder."' reussie", "W" );
+        }
+    }
+
+    if( $folderError ) {
+        return 0;
+    }else {
+        return 1;
+    }
+}
+
 
 sub _updateMailbox {
     my $self = shift;
