@@ -55,6 +55,8 @@ sub configure_hook {
         transport_map => [],
         process_domain => [],
         domain_map => [],
+        process_transport_smtp => [],
+        transport_smtp_map => [],
         cyrus_service => [],
         cyrus_imap_conf => [],
         cyrus_restart => [],
@@ -97,35 +99,78 @@ sub configure_hook {
     }
 
     # La table des BALs
-    if( $daemonOptions->{process_mailbox}->[0] =~ /^[01]$/ ) {
+    if( (defined($daemonOptions->{process_mailbox}->[0])) && ($daemonOptions->{process_mailbox}->[0] =~ /^[01]$/ )) {
         $self->{postfix_maps}->{mailbox}->{postfix_map_process} = $daemonOptions->{process_mailbox}->[0];
-    }
-    if( defined($daemonOptions->{mailbox_map}->[0]) ) {
-        $self->{postfix_maps}->{mailbox}->{postfix_map} = $daemonOptions->{mailbox_map}->[0];
+
+        if( $self->{postfix_maps}->{mailbox}->{postfix_map_process} ) {
+            if( defined($daemonOptions->{mailbox_map}->[0]) ) {
+                $self->{postfix_maps}->{mailbox}->{postfix_map} = $daemonOptions->{mailbox_map}->[0];
+            }else {
+                $self->{postfix_maps}->{mailbox}->{postfix_map} = "/etc/postfix/virtual_mailbox";
+            }
+        }
+    }else {
+        $self->{postfix_maps}->{mailbox}->{postfix_map_process} = 0;
     }
 
     # La table des alias
-    if( $daemonOptions->{process_alias}->[0] =~ /^[01]$/ ) {
+    if( (defined($daemonOptions->{process_alias}->[0])) && ($daemonOptions->{process_alias}->[0] =~ /^[01]$/ )) {
         $self->{postfix_maps}->{alias}->{postfix_map_process} = $daemonOptions->{process_alias}->[0];
-    }
-    if( defined($daemonOptions->{alias_map}->[0]) ) {
-        $self->{postfix_maps}->{alias}->{postfix_map} = $daemonOptions->{alias_map}->[0];
+
+        if( $self->{postfix_maps}->{alias}->{postfix_map_process} ) {
+            if( defined($daemonOptions->{alias_map}->[0]) ) {
+                $self->{postfix_maps}->{alias}->{postfix_map} = $daemonOptions->{alias_map}->[0];
+            }else {
+                $self->{postfix_maps}->{alias}->{postfix_map} = "/etc/postfix/virtual_alias";
+            }
+        }
+    }else {
+        $self->{postfix_maps}->{alias}->{postfix_map_process} = 0;
     }
 
-    # La table de transport
-    if( $daemonOptions->{process_transport}->[0] =~ /^[01]$/ ) {
+    # La table de transport LMTP
+    if( (defined($daemonOptions->{process_transport}->[0])) && ($daemonOptions->{process_transport}->[0] =~ /^[01]$/ )) {
         $self->{postfix_maps}->{transport}->{postfix_map_process} = $daemonOptions->{process_transport}->[0];
-    }
-    if( defined($daemonOptions->{transport_map}->[0]) ) {
-        $self->{postfix_maps}->{transport}->{postfix_map} = $daemonOptions->{transport_map}->[0];
+
+        if( $self->{postfix_maps}->{transport}->{postfix_map_process} ) {
+            if( defined($daemonOptions->{transport_map}->[0]) ) {
+                $self->{postfix_maps}->{transport}->{postfix_map} = $daemonOptions->{transport_map}->[0];
+            }else {
+                $self->{postfix_maps}->{transport}->{postfix_map} = "/etc/postfix/transport";
+            }
+        }
+    }else {
+        $self->{postfix_maps}->{transport}->{postfix_map_process} = 0;
     }
 
     # La table des domaines
-    if( $daemonOptions->{process_domain}->[0] =~ /^[01]$/ ) {
+    if( (defined($daemonOptions->{process_domain}->[0])) && ($daemonOptions->{process_domain}->[0] =~ /^[01]$/ )) {
         $self->{postfix_maps}->{domain}->{postfix_map_process} = $daemonOptions->{process_domain}->[0];
+
+        if( $self->{postfix_maps}->{domain}->{postfix_map_process} ) {
+            if( defined($daemonOptions->{domain_map}->[0]) ) {
+                $self->{postfix_maps}->{domain}->{postfix_map} = $daemonOptions->{domain_map}->[0];
+            }else {
+                $self->{postfix_maps}->{domain}->{postfix_map} = "/etc/postfix/virtual_domains"
+            }
+        }
+    }else {
+        $self->{postfix_maps}->{domain}->{postfix_map_process} = 0;
     }
-    if( defined($daemonOptions->{domain_map}->[0]) ) {
-        $self->{postfix_maps}->{domain}->{postfix_map} = $daemonOptions->{domain_map}->[0];
+
+    # La table de transport SMTP
+    if( (defined($daemonOptions->{process_transport_smtp}->[0])) && ($daemonOptions->{process_transport_smtp}->[0] =~ /^[01]$/ )) {
+        $self->{postfix_maps}->{transport_smtp}->{postfix_map_process} = $daemonOptions->{process_transport_smtp}->[0];
+
+        if( $self->{postfix_maps}->{transport_smtp}->{postfix_map_process} ) {
+            if( defined($daemonOptions->{transport_smtp_map}->[0]) ) {
+                $self->{postfix_maps}->{transport_smtp}->{postfix_map} = $daemonOptions->{transport_smtp_map}->[0];
+            }else {
+                $self->{postfix_maps}->{transport_smtp}->{postfix_map} = "/etc/postfix/transport_smtp";
+            }
+        }
+    }else {
+        $self->{postfix_maps}->{transport_smtp}->{postfix_map_process} = 0;
     }
 
     # Le script du service Cyrus
@@ -260,6 +305,18 @@ sub process_request {
                     }
                 }
 
+                if( $currentRequest =~ /^smtpOutConf: ([A-Za-z0-9][A-Za-z0-9-]{0,30}[A-Za-z0-9])$/i ) {
+                    my $hostName = $1;
+
+                    my $domainList = $self->getServerDomains( "smtp_out", $hostName );
+                    if( !defined($domainList) || ( ref($domainList) ne "ARRAY" ) ) {
+                        $self->logMessage( "L'hote '".$hostName."' n'est serveur SMTP sortant d'aucun domaine" );
+                        $self->sendMessage( "ERROR", $hostName." n'est pas un serveur SMTP sortant" );
+                    }else {
+                        $self->processPostfixDomains( $domainList );
+                    }
+                }
+
                 if( $currentRequest =~ /^cyrusPartitions: (add|del):([A-Za-z0-9][A-Za-z0-9-]{0,30}[A-Za-z0-9])$/i ) {
                     my $action = $1;
                     my $hostName = $2;
@@ -405,6 +462,10 @@ sub checkClientRequest {
             return 0;
         }
         
+        if( $$request =~ /^smtpOutConf: (.+:)*.+$/i ) {
+            return 0;
+        }
+        
         if( $$request =~ /^cyrusPartitions: (.+:)*.+$/i ) {
             return 0;
         }
@@ -438,6 +499,12 @@ sub getServerDomains {
             last SWITCH;
         }
 
+        if( $type =~ /^smtp_out$/ ) {
+            $self->logMessage( "Obtention des domaines du serveur '".$hostName."' de type SMTP-out" );
+            $ldapFilter = "smtpOutHost=".$hostName;
+            last SWITCH;
+        }
+
         if( $type =~ /^imap$/ ) {
             $self->logMessage( "Obtention des domaines du serveur '".$hostName."' de type IMAP" );
             $ldapFilter = "imapHost=".$hostName;
