@@ -1,23 +1,4 @@
 <?php
-/*
- +-------------------------------------------------------------------------+
- |  Copyright (c) 1997-2008 Aliasource - Groupe LINAGORA                   |
- |                                                                         |
- | This program is free software; you can redistribute it and/or           |
- | modify it under the terms of the GNU General Public License             |
- | as published by the Free Software Foundation; either version 2          |
- | of the License, or (at your option) any later version.                  |
- |                                                                         |
- | This program is distributed in the hope that it will be useful,         |
- | but WITHOUT ANY WARRANTY; without even the implied warranty of          |
- | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
- | GNU General Public License for more details.                            |
- +-------------------------------------------------------------------------+
- | http://obm.aliasource.fr/                                               |
- +-------------------------------------------------------------------------+
-*/
-?>
-<?php
 ///////////////////////////////////////////////////////////////////////////////
 // OBM - File : admin_ref_index.php                                          //
 //     - Desc : Referential data index file                                  //
