@@ -1,29 +1,10 @@
 <?php
-/*
- +-------------------------------------------------------------------------+
- |  Copyright (c) 1997-2008 Aliasource - Groupe LINAGORA                   |
- |                                                                         |
- | This program is free software; you can redistribute it and/or           |
- | modify it under the terms of the GNU General Public License             |
- | as published by the Free Software Foundation; either version 2          |
- | of the License, or (at your option) any later version.                  |
- |                                                                         |
- | This program is distributed in the hope that it will be useful,         |
- | but WITHOUT ANY WARRANTY; without even the implied warranty of          |
- | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
- | GNU General Public License for more details.                            |
- +-------------------------------------------------------------------------+
- | http://obm.aliasource.fr/                                               |
- +-------------------------------------------------------------------------+
-*/
-?>
-<?php
 ///////////////////////////////////////////////////////////////////////////////
 // OBM - File : calendar_index.php                                           //
 //     - Desc : Calendar Index File                                          //
 // 2002-11-26 - Mehdi Rande                                                  //
 ///////////////////////////////////////////////////////////////////////////////
-// $Id: calendar_index.php 2849 2008-03-26 13:32:14Z pierre $ //
+// $Id: calendar_index.php 2910 2008-05-22 22:57:41Z pierre $ //
 ///////////////////////////////////////////////////////////////////////////////
 // Actions :
 // - index (default) -- this week for this user.
@@ -69,7 +50,7 @@ if (isset($params['cal_view'])) {
 } elseif (isset($_SESSION['cal_view'])){
   $cal_view = $_SESSION['cal_view'];
 } else {
-  $cal_view = "agenda";
+  $cal_view = 'agenda';
 }
 if (isset($params['cal_range'])) {
   $cal_range = $params['cal_range'];
@@ -88,7 +69,6 @@ define('RFC2445_FOLDED_LINE_LENGTH', 75);
 $ics_event_priority_to_obm = array(1 => 3, 2 => 3, 3 => 3, 4 => 2, 5 => 2, 6 => 2, 7 => 1, 8 => 1, 9 => 1) ;
 ///////////////////////////////////////////////////////////////////////////////
 
-
 $extra_css[] = $css_calendar;
 $extra_js_include[] = 'calendar.js';
 $extra_js_include[] = 'colorpicker.js';
@@ -103,7 +83,6 @@ get_calendar_action();
 update_calendar_action();
 $perm->check_permissions($module, $action);
 
-
 page_close();
 
 
@@ -533,8 +512,13 @@ if ($action == 'index') {
 } elseif ($action == 'ics_insert')  {
 ///////////////////////////////////////////////////////////////////////////////
   $result = run_query_icalendar_insert($params) ;
-  $display['msg'] .= display_ok_msg("$l_event : $l_insert_ok");
-  $display['detail'] = dis_icalendar_insert($result);
+  if($result !== false) {
+    $display['msg'] .= display_ok_msg("$l_event : $l_insert_ok");
+    $display['detail'] = dis_icalendar_insert($result);
+  } else {
+    $display['msg'] .= display_err_msg("$l_file_format $l_unknown");
+    $display['detail'] .= dis_icalendar_import($params);
+  }
 }
 
 $_SESSION['cal_entity_id'] = $cal_entity_id;
