@@ -1,29 +1,10 @@
 <?php
-/*
- +-------------------------------------------------------------------------+
- |  Copyright (c) 1997-2008 Aliasource - Groupe LINAGORA                   |
- |                                                                         |
- | This program is free software; you can redistribute it and/or           |
- | modify it under the terms of the GNU General Public License             |
- | as published by the Free Software Foundation; either version 2          |
- | of the License, or (at your option) any later version.                  |
- |                                                                         |
- | This program is distributed in the hope that it will be useful,         |
- | but WITHOUT ANY WARRANTY; without even the implied warranty of          |
- | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
- | GNU General Public License for more details.                            |
- +-------------------------------------------------------------------------+
- | http://obm.aliasource.fr/                                               |
- +-------------------------------------------------------------------------+
-*/
-?>
-<?php
 ///////////////////////////////////////////////////////////////////////////////
 // OBM - File : contact_index.php                                            //
 //     - Desc : Contact Index File                                           //
 // 1999-03-19 Pierre Baudracco                                               //
 ///////////////////////////////////////////////////////////////////////////////
-// $Id: contact_index.php 2734 2008-02-14 18:36:58Z mehdi $ //
+// $Id: contact_index.php 2922 2008-06-03 09:47:31Z mehdi $ //
 ///////////////////////////////////////////////////////////////////////////////
 // Actions :
 // - index (default)    -- search fields  -- show the contact search form
@@ -430,7 +411,7 @@ function get_contact_action() {
     'Name'     => $l_header_new,
     'Url'      => "$path/contact/contact_index.php?action=new",
     'Right'    => $cright_write,
-    'Condition'=> array ('','index','search','new','detailconsult','update','statistics','check_delete','delete','admin','display') 
+    'Condition'=> array ('','index','search','insert','new','detailconsult','update','statistics','check_delete','delete','admin','display') 
                                      );
 
 // Detail Consult
