@@ -1,29 +1,10 @@
 <?php
-/*
- +-------------------------------------------------------------------------+
- |  Copyright (c) 1997-2008 Aliasource - Groupe LINAGORA                   |
- |                                                                         |
- | This program is free software; you can redistribute it and/or           |
- | modify it under the terms of the GNU General Public License             |
- | as published by the Free Software Foundation; either version 2          |
- | of the License, or (at your option) any later version.                  |
- |                                                                         |
- | This program is distributed in the hope that it will be useful,         |
- | but WITHOUT ANY WARRANTY; without even the implied warranty of          |
- | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
- | GNU General Public License for more details.                            |
- +-------------------------------------------------------------------------+
- | http://obm.aliasource.fr/                                               |
- +-------------------------------------------------------------------------+
-*/
-?>
-<?php
 ///////////////////////////////////////////////////////////////////////////////
 // OBM - File : document_index.php                                           //
 //     - Desc : Document Index File                                          //
 // 2003-08-21 Rande Mehdi                                                    //
 ///////////////////////////////////////////////////////////////////////////////
-// $Id: document_index.php 2734 2008-02-14 18:36:58Z mehdi $ //
+// $Id: document_index.php 2916 2008-05-29 16:42:52Z mehdi $ //
 ///////////////////////////////////////////////////////////////////////////////
 // Actions              -- Parameter
 // - index (default)    -- search fields  -- show the document search form
@@ -71,7 +52,6 @@ $display["detail"] = html_document_tree($params, $params["ext_disp_file"]);
 
     if ($doc_q->num_rows() == 1) {
       dis_document_file($doc_q);
-      exit();
     }
   } else {
     $display["msg"] .= display_err_msg("$l_no_document !");
