@@ -1,29 +1,10 @@
 <?php
-/*
- +-------------------------------------------------------------------------+
- |  Copyright (c) 1997-2008 Aliasource - Groupe LINAGORA                   |
- |                                                                         |
- | This program is free software; you can redistribute it and/or           |
- | modify it under the terms of the GNU General Public License             |
- | as published by the Free Software Foundation; either version 2          |
- | of the License, or (at your option) any later version.                  |
- |                                                                         |
- | This program is distributed in the hope that it will be useful,         |
- | but WITHOUT ANY WARRANTY; without even the implied warranty of          |
- | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
- | GNU General Public License for more details.                            |
- +-------------------------------------------------------------------------+
- | http://obm.aliasource.fr/                                               |
- +-------------------------------------------------------------------------+
-*/
-?>
-<?php
 ///////////////////////////////////////////////////////////////////////////////
 // OBM - File : group_index.php                                              //
 //     - Desc : Group Index File                                             //
 // 2003-08-22 Pierre Baudracco                                               //
 ///////////////////////////////////////////////////////////////////////////////
-// $Id: group_index.php 2734 2008-02-14 18:36:58Z mehdi $
+// $Id: group_index.php 2877 2008-04-16 17:35:17Z anthony $
 ///////////////////////////////////////////////////////////////////////////////
 // Actions :
 // - index (default) -- search fields  -- show the group search form
@@ -386,7 +367,22 @@ function get_group_params() {
   }
   $params["user_nb"] = $nb_u;
   $params["group_nb"] = $nb_group;
-  
+
+  if(is_array($params['email'])) {
+    $email_aliases = array();
+    while(!empty($params['email'])) {
+      $email = trim(array_shift($params['email']));
+      $domain = array_shift($params['aliases']);
+      if(!empty($email)) {
+       if(!empty($domain)) {
+          $email_aliases[] = $email.'@'.$domain;
+        } else {
+          $email_aliases[] = $email;
+        }
+      }
+    }
+    $params['email'] = implode("\r\n",$email_aliases);
+  } 
   return $params;
 }
 
