@@ -1,34 +1,15 @@
 <?php
-/*
- +-------------------------------------------------------------------------+
- |  Copyright (c) 1997-2008 Aliasource - Groupe LINAGORA                   |
- |                                                                         |
- | This program is free software; you can redistribute it and/or           |
- | modify it under the terms of the GNU General Public License             |
- | as published by the Free Software Foundation; either version 2          |
- | of the License, or (at your option) any later version.                  |
- |                                                                         |
- | This program is distributed in the hope that it will be useful,         |
- | but WITHOUT ANY WARRANTY; without even the implied warranty of          |
- | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
- | GNU General Public License for more details.                            |
- +-------------------------------------------------------------------------+
- | http://obm.aliasource.fr/                                               |
- +-------------------------------------------------------------------------+
-*/
-?>
-<?php
 ///////////////////////////////////////////////////////////////////////////////
 // OBM - File : payment_index.php 
 //     - Desc : payment Index File
 // 2001-08-21 Aliacom, AliaSource
 ///////////////////////////////////////////////////////////////////////////////
-// $Id: payment_index.php 2734 2008-02-14 18:36:58Z mehdi $ //
+// $Id: payment_index.php 2917 2008-05-31 15:08:08Z pierre $ //
 ///////////////////////////////////////////////////////////////////////////////
 
-$path = "..";
-$module = "payment";
-$obminclude = getenv("OBM_INCLUDE_VAR");
+$path = '..';
+$module = 'payment';
+$obminclude = getenv('OBM_INCLUDE_VAR');
 if ($obminclude == "") $obminclude = "obminclude";
 require("$obminclude/global.inc");
 $params = get_payment_params();
@@ -413,13 +394,13 @@ function update_payment_action() {
   if ($id > 0) {
 
     $p = get_payment_info($id);
-    
+    print_r($p);
     // Detail Consult
     $actions["payment"]["detailconsult"]["Url"] = "$path/payment/payment_index.php?action=detailconsult&amp;payment_id=$id";
     $actions["payment"]["detailconsult"]['Condition'][] = 'insert';
 
     // Sel invoice : Invoice selection (menu)
-    $actions["payment"]["sel_invoice"]["Url"] = "$path/invoice/invoice_index.php?action=ext_get_ids&amp;popup=1&amp;ext_action=invoice_add&amp;ext_url=".urlencode($path."/payment/payment_index.php?action=invoice_add&amp;payment_id=$id&amp;sel_invoice_id=")."&amp;ext_id=$id&amp;ext_target=$l_payment&amp;company=$p[company]";
+    $actions["payment"]["sel_invoice"]["Url"] = "$path/invoice/invoice_index.php?action=ext_get_ids&amp;popup=1&amp;ext_action=invoice_add&amp;ext_url=".urlencode($path."/payment/payment_index.php?action=invoice_add&amp;payment_id=$id&amp;sel_invoice_id=")."&amp;ext_id=$id&amp;ext_target=$l_payment&amp;company=".urlencode($p['company']);
     $actions["payment"]["sel_invoice"]['Condition'][] = 'insert';
 
     // Invoice
