@@ -1,29 +1,10 @@
 <?php
-/*
- +-------------------------------------------------------------------------+
- |  Copyright (c) 1997-2008 Aliasource - Groupe LINAGORA                   |
- |                                                                         |
- | This program is free software; you can redistribute it and/or           |
- | modify it under the terms of the GNU General Public License             |
- | as published by the Free Software Foundation; either version 2          |
- | of the License, or (at your option) any later version.                  |
- |                                                                         |
- | This program is distributed in the hope that it will be useful,         |
- | but WITHOUT ANY WARRANTY; without even the implied warranty of          |
- | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
- | GNU General Public License for more details.                            |
- +-------------------------------------------------------------------------+
- | http://obm.aliasource.fr/                                               |
- +-------------------------------------------------------------------------+
-*/
-?>
-<?php
 ///////////////////////////////////////////////////////////////////////////////
 // OBM - File : settings_index.php                                           //
 //     - Desc : Settings (Language, themes,...) management index file        //
 // 1999-03-19 Pierre Baudracco                                               //
 ///////////////////////////////////////////////////////////////////////////////
-// $Id: settings_index.php 2836 2008-03-18 16:33:55Z mehdi $ //
+// $Id: settings_index.php 2909 2008-05-21 08:10:56Z mehdi $ //
 ///////////////////////////////////////////////////////////////////////////////
 
 $path = '..';
@@ -35,7 +16,7 @@ include("$obminclude/global.inc");
 $params = get_settings_params();
 page_open(array('sess' => 'OBM_Session', 'auth' => $auth_class_name, 'perm' => 'OBM_Perm'));
 
-if(!$_SESSION['set_cal_first_hour']) $_SESSION['set_cal_first_hour'] = $ccalendar_first_hour;
+if(!isset($_SESSION['set_cal_first_hour'])) $_SESSION['set_cal_first_hour'] = $ccalendar_first_hour;
 if(!$_SESSION['set_cal_last_hour']) $_SESSION['set_cal_last_hour'] = $ccalendar_last_hour;
 
 if ($params['lang'] != '') {
@@ -122,7 +103,7 @@ if ($params['form_user_pref']) {
     update_user_pref($obm['uid'], 'set_cal_interval', $_SESSION['set_cal_interval'], 1);
   }
 
-  if ($params['cal_first_hour'] != '') {
+  if ($params['cal_first_hour'] !== '') {
     if ($params['cal_first_hour'] >= 0 && $params['cal_first_hour'] <= 24) {
       $_SESSION['set_cal_first_hour'] = $params['cal_first_hour'];
     } else {
@@ -358,7 +339,7 @@ if ($cgp_show['module']['calendar']) {
   $dis_hour_b .= "</select>"; 
 
   $dis_hour_e = "<select name=\"cal_last_hour\" style=\"width:4em;\">";
-  for ($current_hour=0; $current_hour<24; $current_hour++) {
+  for ($current_hour=1; $current_hour<=24; $current_hour++) {
     if ($current_hour == $_SESSION['set_cal_last_hour']) {
       $dis_hour_e .= "<option value=\"$current_hour\" selected=\"selected\">$current_hour</option>";
     } else {
