@@ -1,29 +1,10 @@
 <?php
-/*
- +-------------------------------------------------------------------------+
- |  Copyright (c) 1997-2008 Aliasource - Groupe LINAGORA                   |
- |                                                                         |
- | This program is free software; you can redistribute it and/or           |
- | modify it under the terms of the GNU General Public License             |
- | as published by the Free Software Foundation; either version 2          |
- | of the License, or (at your option) any later version.                  |
- |                                                                         |
- | This program is distributed in the hope that it will be useful,         |
- | but WITHOUT ANY WARRANTY; without even the implied warranty of          |
- | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
- | GNU General Public License for more details.                            |
- +-------------------------------------------------------------------------+
- | http://obm.aliasource.fr/                                               |
- +-------------------------------------------------------------------------+
-*/
-?>
-<?php
 ///////////////////////////////////////////////////////////////////////////////
 // OBM - File : user_index.php                                               //
 //     - Desc : User Index File                                              //
 // 2000-01-13 Florent Goalabre                                               //
 ///////////////////////////////////////////////////////////////////////////////
-// $Id: user_index.php 2760 2008-02-21 17:54:28Z mehdi $ //
+// $Id: user_index.php 2917 2008-05-31 15:08:08Z pierre $ //
 ///////////////////////////////////////////////////////////////////////////////
 // Actions :
 // - index (default) -- search fields  -- show the user search form
@@ -218,7 +199,7 @@ if ($action == "ext_get_ids") {
     }
     $display["search"] = html_user_search_form($params);
   } else {
-    $display["msg"] .= display_warn_msg($err["msg"], false);
+    $display["msg"] .= display_warn_msg($err['msg'], false);
     $display["msg"] .= display_warn_msg($l_cant_delete, false);
     $display["detail"] = dis_user_consult($params);
   }
@@ -316,6 +297,23 @@ function get_user_params() {
     $params['type'] = $_FILES['fi_file']['type'];
   }
 
+  if(is_array($params['email'])) {
+    $email_aliases = array();
+    while(!empty($params['email'])) {
+      $email = trim(array_shift($params['email']));
+      $domain = array_shift($params['aliases']);
+      if(!empty($email)) {
+       if(!empty($domain)) {
+          $email_aliases[] = $email.'@'.$domain;
+        } else {
+          $email_aliases[] = $email;
+        }
+      }
+    }
+
+    $params['email'] = implode("\r\n", $email_aliases);
+  }
+
   return $params;
 }
 
